@@ -26,7 +26,7 @@ class Selenium(Scraper):
 
         options.add_argument('--no-sandbox')
         options.add_argument('--disable-dev-shm-usage')
-        self.driver = webdriver.Remote(command_executor='http://localhost:4444/wd/hub', desired_capabilities={'browserName': 'chrome'}, options=options)
+        self.driver = webdriver.Remote(command_executor='http://selenium:4444/wd/hub', desired_capabilities={'browserName': 'chrome'}, options=options)
 
         # #region undetected_chromedriver
         # # setting profile
